/* 
** ZABBIX
** Copyright (C) 2000-2005 SIA Zabbix
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
**/

#ifndef ZABBIX_POLLER_H
#define ZABBIX_POLLER_H

#include "common.h"
#include "db.h"
#include "sysinfo.h"

extern	void	signal_handler(int);
extern  int     server_num;

extern  int     CONFIG_TIMEOUT;
extern  int     CONFIG_POLLER_FORKS;
extern  int     CONFIG_IPMIPOLLER_FORKS;
extern  int     CONFIG_UNREACHABLE_POLLER_FORKS;
extern  int     CONFIG_UNAVAILABLE_DELAY;
extern  int     CONFIG_UNREACHABLE_PERIOD;
extern  int     CONFIG_UNREACHABLE_DELAY;

void	main_poller_loop(zbx_process_t p, int type, int num);

int	get_value(DB_ITEM *item, AGENT_RESULT *result);

#endif
